@@ -2158,7 +2158,7 @@ yyreduce:
 #line 379 "grammar.y"
         { /* need to reverse map number to string, need to figure out
 	   * how to get auto generation of reverse mapping table into
-	   * autotools Makefile.  For now just drop assumming capname is
+	   * autotools Makefile.  For now just drop assuming capname is
 	   * present which it should be with current kernels */
 	}
 #line 2165 "grammar.c"
@@ -2174,7 +2174,7 @@ yyreduce:
 
   case 81: /* key: TOK_KEY_OFFSET TOK_EQUALS TOK_DIGITS  */
 #line 389 "grammar.y"
-        { /* offset is used for reporting where an error occured unpacking
+        { /* offset is used for reporting where an error occurred unpacking
 	   * loaded policy.  We can just drop this currently
 	   */
 	}
